/**
 * Lato font, a sanserif family designed by Łukasz Dziedzic and others (see
 * http://www.latofonts.com/team) and published under the open-source Open Font License
 * https://scripts.sil.org/cms/scripts/page.php?site_id=nrsi&id=OFL
 *
 * Font files downloaded brom its web page https://www.latofonts.com/
 * Note: At the time of writing, Google Fonts only use the older version (1.0)
 */

/* LatoLatin-Regular */
@font-face {
    font-family: 'Lato';
    src: url('./fonts/LatoLatin-Regular.woff2') format('woff2');
    font-style: normal;
    font-weight: normal;
    text-rendering: optimizeLegibility;
}

/* LatoLatin-Italic */
@font-face {
    font-family: 'Lato';
    src: url('./fonts/LatoLatin-Italic.woff2') format('woff2');
    font-style: italic;
    font-weight: normal;
    text-rendering: optimizeLegibility;
}

/* LatoLatin-Bold */
@font-face {
    font-family: 'Lato';
    src: url('./fonts/LatoLatin-Bold.woff2') format('woff2');
    font-style: normal;
    font-weight: bold;
    text-rendering: optimizeLegibility;
}

/* LatoLatin-BoldItalic */
@font-face {
    font-family: 'Lato';
    src: url('./fonts/LatoLatin-BoldItalic.woff2') format('woff2');
    font-style: italic;
    font-weight: bold;
    text-rendering: optimizeLegibility;
}

/**
 * Poppins is a geometric sans serif designed by Indian Type Foundry and Jonny Pinhorn and licensed
 * under the Open Font License, https://scripts.sil.org/cms/scripts/page.php?site_id=nrsi&id=OFL
 *
 * https://github.com/itfoundry/poppins
 *
 * Fonts files downloaded from Google Fonts https://fonts.google.com/ by using https://github.com/majodev/google-webfonts-helper
 **/

/* poppins-300 - latin-ext_latin_devanagari */
@font-face {
  font-family: 'Poppins';
  font-style: normal;
  font-weight: 300;
  src: local(''),
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-300.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-300.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/* poppins-300italic - latin-ext_latin_devanagari */
@font-face {
  font-family: 'Poppins';
  font-style: italic;
  font-weight: 300;
  src: local(''),
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-300italic.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-300italic.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/* poppins-regular - latin-ext_latin_devanagari */
@font-face {
  font-family: 'Poppins';
  font-style: normal;
  font-weight: 400;
  src: local(''),
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-regular.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-regular.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/* poppins-500 - latin-ext_latin_devanagari */
@font-face {
  font-family: 'Poppins';
  font-style: normal;
  font-weight: 500;
  src: local(''),
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-500.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-500.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/* poppins-500italic - latin-ext_latin_devanagari */
@font-face {
  font-family: 'Poppins';
  font-style: italic;
  font-weight: 500;
  src: local(''),
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-500italic.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('./fonts/poppins-v19-latin-ext_latin_devanagari-500italic.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}

/**
 * Roboto Mono is a monospaced addition to the Roboto type family, designec by Christina Robertson
 * and licensed under Apache License, Version 2.0 http://www.apache.org/licenses/LICENSE-2.0
 *
 * Fonts files downloaded from Google Fonts https://fonts.google.com/ by using https://github.com/majodev/google-webfonts-helper
 */

/* roboto-mono-regular - vietnamese_latin-ext_latin_greek_cyrillic-ext_cyrillic */
@font-face {
  font-family: 'Roboto Mono';
  font-style: normal;
  font-weight: 400;
  src: local(''),
       url('./fonts/roboto-mono-v13-vietnamese_latin-ext_latin_greek_cyrillic-ext_cyrillic-regular.woff2') format('woff2'), /* Chrome 26+, Opera 23+, Firefox 39+ */
       url('./fonts/roboto-mono-v13-vietnamese_latin-ext_latin_greek_cyrillic-ext_cyrillic-regular.woff') format('woff'); /* Chrome 6+, Firefox 3.6+, IE 9+, Safari 5.1+ */
}
